@@ -47,7 +47,6 @@ static GOptionEntry optentries[] =
   {NULL}
 };
 
-static GDBusConnection *bus_connection = NULL;
 static GDBusProxy      *sm_proxy = NULL;
 static char            *client_id = NULL;
 static GDBusProxy      *client_proxy = NULL;
@@ -58,8 +57,6 @@ static GDBusProxy      *client_proxy = NULL;
 
 #define SM_CLIENT_DBUS_INTERFACE "org.gnome.SessionManager.ClientPrivate"
 
-static void registry_session_init (const char *previous_client_id, const char *exe);
-
 static void
 on_session_over (GDBusProxy *proxy,
                  gchar      *sender_name,
@@ -87,12 +84,6 @@ session_manager_connect (void)
         return (sm_proxy != NULL);
 }
 
-static void
-stop_cb (gpointer data)
-{
-        g_main_loop_quit (mainloop);
-}
-
 static gboolean
 end_session_response (gboolean is_okay, const gchar *reason)
 {
